; Freeciv Windows installer script
; some parts adapted from Wesnoth installer script

SetCompressor /SOLID lzma

!define APPNAME "Freeciv"
!define VERSION 2.2.7
!define GUI_ID sdl
!define GUI_NAME SDL
!define APPID "${APPNAME}-${VERSION}-${GUI_ID}"

!define MULTIUSER_EXECUTIONLEVEL Highest
!define MULTIUSER_MUI
!define MULTIUSER_INSTALLMODE_COMMANDLINE
!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}"
!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_VALUENAME ""
!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}"
!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_VALUENAME ""
!define MULTIUSER_INSTALLMODE_INSTDIR "${APPNAME}-${VERSION}-${GUI_ID}"

!include "MultiUser.nsh"
!include "MUI2.nsh"

;General

Name "${APPNAME} ${VERSION} (${GUI_NAME} client)"
OutFile "Output/${APPNAME}-${VERSION}-win32-${GUI_ID}-setup.exe"

;Variables

Var STARTMENU_FOLDER

; Pages

!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "freeciv\COPYING"
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MULTIUSER_PAGE_INSTALLMODE
!insertmacro MUI_PAGE_DIRECTORY

;Start Menu Folder Page Configuration
!define MUI_STARTMENUPAGE_REGISTRY_ROOT "SHCTX" 
!define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}" 
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"
!define MUI_STARTMENUPAGE_DEFAULTFOLDER "$(^Name)"

!insertmacro MUI_PAGE_STARTMENU "Application" $STARTMENU_FOLDER
!insertmacro MUI_PAGE_INSTFILES

!define MUI_FINISHPAGE_RUN "$INSTDIR\freeciv-sdl.exe"
!insertmacro MUI_PAGE_FINISH

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

;Languages

!insertmacro MUI_LANGUAGE "English"

; The stuff to install
Section "${APPNAME} (required)"

  SectionIn RO

  SetOutPath $INSTDIR
  File /nonfatal /r /x locale /x stdsounds.soundspec /x stdsounds /x COPYING.fireflysung /x fireflysung.ttf /x COPYING.sazanami /x sazanami-gothic.ttf /x COPYING.UnDotum /x UnDotum.ttf freeciv\*.*

  ; Write the installation path into the registry
  WriteRegStr "SHCTX" SOFTWARE\${APPNAME}\${VERSION}\${GUI_ID} "" "$INSTDIR"

  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
  CreateDirectory "$SMPROGRAMS\$STARTMENU_FOLDER"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Freeciv Server.lnk" "$INSTDIR\freeciv-server.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Freeciv.lnk" "$INSTDIR\freeciv-sdl.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Uninstall.lnk" "$INSTDIR\uninstall.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Website.lnk" "$INSTDIR\Freeciv.url"
  !insertmacro MUI_STARTMENU_WRITE_END

  ; Write the uninstall keys for Windows
  WriteRegStr "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "DisplayName" "$(^Name)"
  WriteRegStr "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "NoModify" 1
  WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "NoRepair" 1
  WriteUninstaller "uninstall.exe"
  
  SetOutPath $INSTDIR
SectionEnd

SectionGroup "Soundsets"

  Section "stdsounds"
  SetOutPath $INSTDIR\data
  File /r freeciv\data\stdsounds.soundspec
  SetOutPath $INSTDIR\data\stdsounds
  File /r freeciv\data\stdsounds\*.*
  SetOutPath $INSTDIR
  SectionEnd

SectionGroupEnd

SectionGroup "Additional languages"

  Section /o "ar"
  SetOutPath $INSTDIR\share\locale\ar
  File /r freeciv\share\locale\ar\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ca"
  SetOutPath $INSTDIR\share\locale\ca
  File /r freeciv\share\locale\ca\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "cs"
  SetOutPath $INSTDIR\share\locale\cs
  File /r freeciv\share\locale\cs\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "da"
  SetOutPath $INSTDIR\share\locale\da
  File /r freeciv\share\locale\da\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "de"
  SetOutPath $INSTDIR\share\locale\de
  File /r freeciv\share\locale\de\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "el"
  SetOutPath $INSTDIR\share\locale\el
  File /r freeciv\share\locale\el\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "en_GB"
  SetOutPath $INSTDIR\share\locale\en_GB
  File /r freeciv\share\locale\en_GB\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "eo"
  SetOutPath $INSTDIR\share\locale\eo
  File /r freeciv\share\locale\eo\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "es"
  SetOutPath $INSTDIR\share\locale\es
  File /r freeciv\share\locale\es\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "et"
  SetOutPath $INSTDIR\share\locale\et
  File /r freeciv\share\locale\et\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fa"
  SetOutPath $INSTDIR\share\locale\fa
  File /r freeciv\share\locale\fa\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fi"
  SetOutPath $INSTDIR\share\locale\fi
  File /r freeciv\share\locale\fi\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fr"
  SetOutPath $INSTDIR\share\locale\fr
  File /r freeciv\share\locale\fr\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "he"
  SetOutPath $INSTDIR\share\locale\he
  File /r freeciv\share\locale\he\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "hu"
  SetOutPath $INSTDIR\share\locale\hu
  File /r freeciv\share\locale\hu\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "it"
  SetOutPath $INSTDIR\share\locale\it
  File /r freeciv\share\locale\it\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ja"
  SetOutPath $INSTDIR\share\locale\ja
  File /r freeciv\share\locale\ja\*.*
  SetOutPath $INSTDIR\data\themes\gui-sdl\human
  File /r freeciv\data\themes\gui-sdl\human\COPYING.sazanami
  File /r freeciv\data\themes\gui-sdl\human\sazanami-gothic.ttf
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ko"
  SetOutPath $INSTDIR\share\locale\ko
  File /r freeciv\share\locale\ko\*.*
  SetOutPath $INSTDIR\data\themes\gui-sdl\human
  File /r freeciv\data\themes\gui-sdl\human\COPYING.UnDotum
  File /r freeciv\data\themes\gui-sdl\human\UnDotum.ttf
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "lt"
  SetOutPath $INSTDIR\share\locale\lt
  File /r freeciv\share\locale\lt\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "nb"
  SetOutPath $INSTDIR\share\locale\nb
  File /r freeciv\share\locale\nb\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "nl"
  SetOutPath $INSTDIR\share\locale\nl
  File /r freeciv\share\locale\nl\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "no"
  SetOutPath $INSTDIR\share\locale\no
  File /r freeciv\share\locale\no\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pl"
  SetOutPath $INSTDIR\share\locale\pl
  File /r freeciv\share\locale\pl\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pt"
  SetOutPath $INSTDIR\share\locale\pt
  File /r freeciv\share\locale\pt\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pt_BR"
  SetOutPath $INSTDIR\share\locale\pt_BR
  File /r freeciv\share\locale\pt_BR\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ro"
  SetOutPath $INSTDIR\share\locale\ro
  File /r freeciv\share\locale\ro\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ru"
  SetOutPath $INSTDIR\share\locale\ru
  File /r freeciv\share\locale\ru\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "sv"
  SetOutPath $INSTDIR\share\locale\sv
  File /r freeciv\share\locale\sv\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "tr"
  SetOutPath $INSTDIR\share\locale\tr
  File /r freeciv\share\locale\tr\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "uk"
  SetOutPath $INSTDIR\share\locale\uk
  File /r freeciv\share\locale\uk\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "zh_CN"
  SetOutPath $INSTDIR\share\locale\zh_CN
  File /r freeciv\share\locale\zh_CN\*.*
  SetOutPath $INSTDIR\data\themes\gui-sdl\human
  File /r freeciv\data\themes\gui-sdl\human\COPYING.fireflysung
  File /r freeciv\data\themes\gui-sdl\human\fireflysung.ttf
  SetOutPath $INSTDIR
  SectionEnd

SectionGroupEnd

;--------------------------------
;Installer Functions

Function .onInit

  !insertmacro MULTIUSER_INIT

FunctionEnd

; special uninstall section.
Section "Uninstall"

  ; remove files
  Delete "$INSTDIR\ABOUT-NLS"
  Delete "$INSTDIR\AUTHORS"
  Delete "$INSTDIR\ChangeLog"
  Delete "$INSTDIR\civmanual.exe"
  Delete "$INSTDIR\COPYING"
  Delete "$INSTDIR\data\amplio\ancientcities.png"
  Delete "$INSTDIR\data\amplio\ancientcities.spec"
  Delete "$INSTDIR\data\amplio\buildings.spec"
  Delete "$INSTDIR\data\amplio\cityicon.png"
  Delete "$INSTDIR\data\amplio\civicon.png"
  Delete "$INSTDIR\data\amplio\explosions.png"
  Delete "$INSTDIR\data\amplio\explosions.spec"
  Delete "$INSTDIR\data\amplio\fog.png"
  Delete "$INSTDIR\data\amplio\fog.spec"
  Delete "$INSTDIR\data\amplio\grid.png"
  Delete "$INSTDIR\data\amplio\grid.spec"
  Delete "$INSTDIR\data\amplio\icons.spec"
  Delete "$INSTDIR\data\amplio\medievalcities.png"
  Delete "$INSTDIR\data\amplio\medievalcities.spec"
  Delete "$INSTDIR\data\amplio\moderncities.png"
  Delete "$INSTDIR\data\amplio\moderncities.spec"
  Delete "$INSTDIR\data\amplio\nuke.png"
  Delete "$INSTDIR\data\amplio\nuke.spec"
  Delete "$INSTDIR\data\amplio\ocean.png"
  Delete "$INSTDIR\data\amplio\ocean.spec"
  Delete "$INSTDIR\data\amplio\select-alpha.png"
  Delete "$INSTDIR\data\amplio\select.png"
  Delete "$INSTDIR\data\amplio\select.spec"
  Delete "$INSTDIR\data\amplio\terrain1.png"
  Delete "$INSTDIR\data\amplio\terrain1.spec"
  Delete "$INSTDIR\data\amplio\terrain2.png"
  Delete "$INSTDIR\data\amplio\terrain2.spec"
  Delete "$INSTDIR\data\amplio\tiles.png"
  Delete "$INSTDIR\data\amplio\tiles.spec"
  Delete "$INSTDIR\data\amplio\units.png"
  Delete "$INSTDIR\data\amplio\units.spec"
  Delete "$INSTDIR\data\amplio\water.png"
  Delete "$INSTDIR\data\amplio\water.spec"
  Delete "$INSTDIR\data\amplio\wonders.spec"
  Delete "$INSTDIR\data\amplio.tilespec"
  Delete "$INSTDIR\data\buildings\airport.png"
  Delete "$INSTDIR\data\buildings\aqueduct.png"
  Delete "$INSTDIR\data\buildings\bank.png"
  Delete "$INSTDIR\data\buildings\barracks_i.png"
  Delete "$INSTDIR\data\buildings\barracks_ii.png"
  Delete "$INSTDIR\data\buildings\barracks_iii.png"
  Delete "$INSTDIR\data\buildings\capitalization.png"
  Delete "$INSTDIR\data\buildings\cathedral.png"
  Delete "$INSTDIR\data\buildings\city_walls.png"
  Delete "$INSTDIR\data\buildings\coastal_defense.png"
  Delete "$INSTDIR\data\buildings\colosseum.png"
  Delete "$INSTDIR\data\buildings\courthouse.png"
  Delete "$INSTDIR\data\buildings\factory.png"
  Delete "$INSTDIR\data\buildings\granary.png"
  Delete "$INSTDIR\data\buildings\harbor.png"
  Delete "$INSTDIR\data\buildings\hydro_plant.png"
  Delete "$INSTDIR\data\buildings\library.png"
  Delete "$INSTDIR\data\buildings\marketplace.png"
  Delete "$INSTDIR\data\buildings\mass_transit.png"
  Delete "$INSTDIR\data\buildings\mfg_plant.png"
  Delete "$INSTDIR\data\buildings\nuclear_plant.png"
  Delete "$INSTDIR\data\buildings\offshore_platform.png"
  Delete "$INSTDIR\data\buildings\palace.png"
  Delete "$INSTDIR\data\buildings\police_station.png"
  Delete "$INSTDIR\data\buildings\port_facility.png"
  Delete "$INSTDIR\data\buildings\power_plant.png"
  Delete "$INSTDIR\data\buildings\recycling_center.png"
  Delete "$INSTDIR\data\buildings\research_lab.png"
  Delete "$INSTDIR\data\buildings\sam_battery.png"
  Delete "$INSTDIR\data\buildings\sdi_defense.png"
  Delete "$INSTDIR\data\buildings\sewer_system.png"
  Delete "$INSTDIR\data\buildings\solar_plant.png"
  Delete "$INSTDIR\data\buildings\space_component.png"
  Delete "$INSTDIR\data\buildings\space_modules.png"
  Delete "$INSTDIR\data\buildings\space_structural.png"
  Delete "$INSTDIR\data\buildings\stock_exchange.png"
  Delete "$INSTDIR\data\buildings\supermarket.png"
  Delete "$INSTDIR\data\buildings\super_highways.png"
  Delete "$INSTDIR\data\buildings\temple.png"
  Delete "$INSTDIR\data\buildings\university.png"
  Delete "$INSTDIR\data\civ1\buildings.ruleset"
  Delete "$INSTDIR\data\civ1\cities.ruleset"
  Delete "$INSTDIR\data\civ1\effects.ruleset"
  Delete "$INSTDIR\data\civ1\game.ruleset"
  Delete "$INSTDIR\data\civ1\governments.ruleset"
  Delete "$INSTDIR\data\civ1\nations.ruleset"
  Delete "$INSTDIR\data\civ1\techs.ruleset"
  Delete "$INSTDIR\data\civ1\terrain.ruleset"
  Delete "$INSTDIR\data\civ1\units.ruleset"
  Delete "$INSTDIR\data\civ1.serv"
  Delete "$INSTDIR\data\civ2\buildings.ruleset"
  Delete "$INSTDIR\data\civ2\cities.ruleset"
  Delete "$INSTDIR\data\civ2\effects.ruleset"
  Delete "$INSTDIR\data\civ2\game.ruleset"
  Delete "$INSTDIR\data\civ2\governments.ruleset"
  Delete "$INSTDIR\data\civ2\techs.ruleset"
  Delete "$INSTDIR\data\civ2\terrain.ruleset"
  Delete "$INSTDIR\data\civ2\units.ruleset"
  Delete "$INSTDIR\data\civ2.serv"
  Delete "$INSTDIR\data\default\ai_effects.ruleset"
  Delete "$INSTDIR\data\default\buildings.ruleset"
  Delete "$INSTDIR\data\default\cities.ruleset"
  Delete "$INSTDIR\data\default\default.lua"
  Delete "$INSTDIR\data\default\effects.ruleset"
  Delete "$INSTDIR\data\default\game.ruleset"
  Delete "$INSTDIR\data\default\governments.ruleset"
  Delete "$INSTDIR\data\default\nations.ruleset"
  Delete "$INSTDIR\data\default\script.lua"
  Delete "$INSTDIR\data\default\techs.ruleset"
  Delete "$INSTDIR\data\default\terrain.ruleset"
  Delete "$INSTDIR\data\default\units.ruleset"
  Delete "$INSTDIR\data\default.serv"
  Delete "$INSTDIR\data\flags\aborigines-shield.png"
  Delete "$INSTDIR\data\flags\aborigines.png"
  Delete "$INSTDIR\data\flags\afghanistan-shield.png"
  Delete "$INSTDIR\data\flags\afghanistan.png"
  Delete "$INSTDIR\data\flags\ainu-shield.png"
  Delete "$INSTDIR\data\flags\ainu.png"
  Delete "$INSTDIR\data\flags\akwe-shield.png"
  Delete "$INSTDIR\data\flags\akwe.png"
  Delete "$INSTDIR\data\flags\algeria-shield.png"
  Delete "$INSTDIR\data\flags\algeria.png"
  Delete "$INSTDIR\data\flags\antarctica-shield.png"
  Delete "$INSTDIR\data\flags\antarctica.png"
  Delete "$INSTDIR\data\flags\arab-shield.png"
  Delete "$INSTDIR\data\flags\arab.png"
  Delete "$INSTDIR\data\flags\aram-shield.png"
  Delete "$INSTDIR\data\flags\aram.png"
  Delete "$INSTDIR\data\flags\argentina-shield.png"
  Delete "$INSTDIR\data\flags\argentina.png"
  Delete "$INSTDIR\data\flags\armenia-shield.png"
  Delete "$INSTDIR\data\flags\armenia.png"
  Delete "$INSTDIR\data\flags\assyria-shield.png"
  Delete "$INSTDIR\data\flags\assyria.png"
  Delete "$INSTDIR\data\flags\australia-shield.png"
  Delete "$INSTDIR\data\flags\australia.png"
  Delete "$INSTDIR\data\flags\austria-shield.png"
  Delete "$INSTDIR\data\flags\austria.png"
  Delete "$INSTDIR\data\flags\aymara-shield.png"
  Delete "$INSTDIR\data\flags\aymara.png"
  Delete "$INSTDIR\data\flags\azerbaijan-shield.png"
  Delete "$INSTDIR\data\flags\azerbaijan.png"
  Delete "$INSTDIR\data\flags\aztec-shield.png"
  Delete "$INSTDIR\data\flags\aztec.png"
  Delete "$INSTDIR\data\flags\babylon-shield.png"
  Delete "$INSTDIR\data\flags\babylon.png"
  Delete "$INSTDIR\data\flags\bangladesh-shield.png"
  Delete "$INSTDIR\data\flags\bangladesh.png"
  Delete "$INSTDIR\data\flags\barbarian-shield.png"
  Delete "$INSTDIR\data\flags\barbarian.png"
  Delete "$INSTDIR\data\flags\bavarian-shield.png"
  Delete "$INSTDIR\data\flags\bavarian.png"
  Delete "$INSTDIR\data\flags\belarus-shield.png"
  Delete "$INSTDIR\data\flags\belarus.png"
  Delete "$INSTDIR\data\flags\belgium-shield.png"
  Delete "$INSTDIR\data\flags\belgium.png"
  Delete "$INSTDIR\data\flags\boer-shield.png"
  Delete "$INSTDIR\data\flags\boer.png"
  Delete "$INSTDIR\data\flags\bosnia-shield.png"
  Delete "$INSTDIR\data\flags\bosnia.png"
  Delete "$INSTDIR\data\flags\brasil-shield.png"
  Delete "$INSTDIR\data\flags\brasil.png"
  Delete "$INSTDIR\data\flags\brittany-shield.png"
  Delete "$INSTDIR\data\flags\brittany.png"
  Delete "$INSTDIR\data\flags\bulgaria-shield.png"
  Delete "$INSTDIR\data\flags\bulgaria.png"
  Delete "$INSTDIR\data\flags\burgundy-shield.png"
  Delete "$INSTDIR\data\flags\burgundy.png"
  Delete "$INSTDIR\data\flags\burundi-shield.png"
  Delete "$INSTDIR\data\flags\burundi.png"
  Delete "$INSTDIR\data\flags\byzantium-shield.png"
  Delete "$INSTDIR\data\flags\byzantium.png"
  Delete "$INSTDIR\data\flags\canada-shield.png"
  Delete "$INSTDIR\data\flags\canada.png"
  Delete "$INSTDIR\data\flags\cartago-shield.png"
  Delete "$INSTDIR\data\flags\cartago.png"
  Delete "$INSTDIR\data\flags\catalan-shield.png"
  Delete "$INSTDIR\data\flags\catalan.png"
  Delete "$INSTDIR\data\flags\cheyenne-shield.png"
  Delete "$INSTDIR\data\flags\cheyenne.png"
  Delete "$INSTDIR\data\flags\chile-shield.png"
  Delete "$INSTDIR\data\flags\chile.png"
  Delete "$INSTDIR\data\flags\china-shield.png"
  Delete "$INSTDIR\data\flags\china.png"
  Delete "$INSTDIR\data\flags\chola-shield.png"
  Delete "$INSTDIR\data\flags\chola.png"
  Delete "$INSTDIR\data\flags\colombia-shield.png"
  Delete "$INSTDIR\data\flags\colombia.png"
  Delete "$INSTDIR\data\flags\constantine-shield.png"
  Delete "$INSTDIR\data\flags\constantine.png"
  Delete "$INSTDIR\data\flags\cornwall-shield.png"
  Delete "$INSTDIR\data\flags\cornwall.png"
  Delete "$INSTDIR\data\flags\croatia-shield.png"
  Delete "$INSTDIR\data\flags\croatia.png"
  Delete "$INSTDIR\data\flags\cuba-shield.png"
  Delete "$INSTDIR\data\flags\cuba.png"
  Delete "$INSTDIR\data\flags\czech-shield.png"
  Delete "$INSTDIR\data\flags\czech.png"
  Delete "$INSTDIR\data\flags\denmark-shield.png"
  Delete "$INSTDIR\data\flags\denmark.png"
  Delete "$INSTDIR\data\flags\dominica-shield.png"
  Delete "$INSTDIR\data\flags\dominica.png"
  Delete "$INSTDIR\data\flags\egypt-shield.png"
  Delete "$INSTDIR\data\flags\egypt.png"
  Delete "$INSTDIR\data\flags\egypt_ancient-shield.png"
  Delete "$INSTDIR\data\flags\egypt_ancient.png"
  Delete "$INSTDIR\data\flags\england-shield.png"
  Delete "$INSTDIR\data\flags\england.png"
  Delete "$INSTDIR\data\flags\esperanto-shield.png"
  Delete "$INSTDIR\data\flags\esperanto.png"
  Delete "$INSTDIR\data\flags\estonia-shield.png"
  Delete "$INSTDIR\data\flags\estonia.png"
  Delete "$INSTDIR\data\flags\ethiopia-shield.png"
  Delete "$INSTDIR\data\flags\ethiopia.png"
  Delete "$INSTDIR\data\flags\europe-shield.png"
  Delete "$INSTDIR\data\flags\europe.png"
  Delete "$INSTDIR\data\flags\euskadi-shield.png"
  Delete "$INSTDIR\data\flags\euskadi.png"
  Delete "$INSTDIR\data\flags\finland-shield.png"
  Delete "$INSTDIR\data\flags\finland.png"
  Delete "$INSTDIR\data\flags\france-shield.png"
  Delete "$INSTDIR\data\flags\france.png"
  Delete "$INSTDIR\data\flags\france_old-shield.png"
  Delete "$INSTDIR\data\flags\france_old.png"
  Delete "$INSTDIR\data\flags\galicia-shield.png"
  Delete "$INSTDIR\data\flags\galicia.png"
  Delete "$INSTDIR\data\flags\gaul-shield.png"
  Delete "$INSTDIR\data\flags\gaul.png"
  Delete "$INSTDIR\data\flags\georgia-shield.png"
  Delete "$INSTDIR\data\flags\georgia.png"
  Delete "$INSTDIR\data\flags\germany-shield.png"
  Delete "$INSTDIR\data\flags\germany.png"
  Delete "$INSTDIR\data\flags\greece-shield.png"
  Delete "$INSTDIR\data\flags\greece.png"
  Delete "$INSTDIR\data\flags\greece_ancient-shield.png"
  Delete "$INSTDIR\data\flags\greece_ancient.png"
  Delete "$INSTDIR\data\flags\greenland-shield.png"
  Delete "$INSTDIR\data\flags\greenland.png"
  Delete "$INSTDIR\data\flags\gupta-shield.png"
  Delete "$INSTDIR\data\flags\gupta.png"
  Delete "$INSTDIR\data\flags\hacker-shield.png"
  Delete "$INSTDIR\data\flags\hacker.png"
  Delete "$INSTDIR\data\flags\hawaii-shield.png"
  Delete "$INSTDIR\data\flags\hawaii.png"
  Delete "$INSTDIR\data\flags\himyar-shield.png"
  Delete "$INSTDIR\data\flags\himyar.png"
  Delete "$INSTDIR\data\flags\hittite-shield.png"
  Delete "$INSTDIR\data\flags\hittite.png"
  Delete "$INSTDIR\data\flags\hopi-shield.png"
  Delete "$INSTDIR\data\flags\hopi.png"
  Delete "$INSTDIR\data\flags\hungary-shield.png"
  Delete "$INSTDIR\data\flags\hungary.png"
  Delete "$INSTDIR\data\flags\iceland-shield.png"
  Delete "$INSTDIR\data\flags\iceland.png"
  Delete "$INSTDIR\data\flags\illyria-shield.png"
  Delete "$INSTDIR\data\flags\illyria.png"
  Delete "$INSTDIR\data\flags\inca-shield.png"
  Delete "$INSTDIR\data\flags\inca.png"
  Delete "$INSTDIR\data\flags\india-shield.png"
  Delete "$INSTDIR\data\flags\india.png"
  Delete "$INSTDIR\data\flags\indonesia-shield.png"
  Delete "$INSTDIR\data\flags\indonesia.png"
  Delete "$INSTDIR\data\flags\innu-shield.png"
  Delete "$INSTDIR\data\flags\innu.png"
  Delete "$INSTDIR\data\flags\iran-shield.png"
  Delete "$INSTDIR\data\flags\iran.png"
  Delete "$INSTDIR\data\flags\iran_ancient-shield.png"
  Delete "$INSTDIR\data\flags\iran_ancient.png"
  Delete "$INSTDIR\data\flags\iraq-shield.png"
  Delete "$INSTDIR\data\flags\iraq.png"
  Delete "$INSTDIR\data\flags\iraq_old-shield.png"
  Delete "$INSTDIR\data\flags\iraq_old.png"
  Delete "$INSTDIR\data\flags\ireland-shield.png"
  Delete "$INSTDIR\data\flags\ireland.png"
  Delete "$INSTDIR\data\flags\iroquois-shield.png"
  Delete "$INSTDIR\data\flags\iroquois.png"
  Delete "$INSTDIR\data\flags\israel-shield.png"
  Delete "$INSTDIR\data\flags\israel.png"
  Delete "$INSTDIR\data\flags\italy-shield.png"
  Delete "$INSTDIR\data\flags\italy.png"
  Delete "$INSTDIR\data\flags\japan-shield.png"
  Delete "$INSTDIR\data\flags\japan.png"
  Delete "$INSTDIR\data\flags\jbonai-shield.png"
  Delete "$INSTDIR\data\flags\jbonai.png"
  Delete "$INSTDIR\data\flags\kampuchea-shield.png"
  Delete "$INSTDIR\data\flags\kampuchea.png"
  Delete "$INSTDIR\data\flags\kanem-bornu-shield.png"
  Delete "$INSTDIR\data\flags\kanem-bornu.png"
  Delete "$INSTDIR\data\flags\kazakhstan-shield.png"
  Delete "$INSTDIR\data\flags\kazakhstan.png"
  Delete "$INSTDIR\data\flags\keetoowah-shield.png"
  Delete "$INSTDIR\data\flags\keetoowah.png"
  Delete "$INSTDIR\data\flags\kenya-shield.png"
  Delete "$INSTDIR\data\flags\kenya.png"
  Delete "$INSTDIR\data\flags\khwarezm-shield.png"
  Delete "$INSTDIR\data\flags\khwarezm.png"
  Delete "$INSTDIR\data\flags\kongo-shield.png"
  Delete "$INSTDIR\data\flags\kongo.png"
  Delete "$INSTDIR\data\flags\korea-shield.png"
  Delete "$INSTDIR\data\flags\korea.png"
  Delete "$INSTDIR\data\flags\korea_ancient-shield.png"
  Delete "$INSTDIR\data\flags\korea_ancient.png"
  Delete "$INSTDIR\data\flags\kurd-shield.png"
  Delete "$INSTDIR\data\flags\kurd.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan-shield.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan.png"
  Delete "$INSTDIR\data\flags\laos-shield.png"
  Delete "$INSTDIR\data\flags\laos.png"
  Delete "$INSTDIR\data\flags\latvia-shield.png"
  Delete "$INSTDIR\data\flags\latvia.png"
  Delete "$INSTDIR\data\flags\libya-shield.png"
  Delete "$INSTDIR\data\flags\libya.png"
  Delete "$INSTDIR\data\flags\lithuania-shield.png"
  Delete "$INSTDIR\data\flags\lithuania.png"
  Delete "$INSTDIR\data\flags\macedonia-shield.png"
  Delete "$INSTDIR\data\flags\macedonia.png"
  Delete "$INSTDIR\data\flags\madagascar-shield.png"
  Delete "$INSTDIR\data\flags\madagascar.png"
  Delete "$INSTDIR\data\flags\majapahit-shield.png"
  Delete "$INSTDIR\data\flags\majapahit.png"
  Delete "$INSTDIR\data\flags\malaysia-shield.png"
  Delete "$INSTDIR\data\flags\malaysia.png"
  Delete "$INSTDIR\data\flags\mali-shield.png"
  Delete "$INSTDIR\data\flags\mali.png"
  Delete "$INSTDIR\data\flags\maori-shield.png"
  Delete "$INSTDIR\data\flags\maori.png"
  Delete "$INSTDIR\data\flags\mapuche-shield.png"
  Delete "$INSTDIR\data\flags\mapuche.png"
  Delete "$INSTDIR\data\flags\mars-shield.png"
  Delete "$INSTDIR\data\flags\mars.png"
  Delete "$INSTDIR\data\flags\maya-shield.png"
  Delete "$INSTDIR\data\flags\maya.png"
  Delete "$INSTDIR\data\flags\mexico-shield.png"
  Delete "$INSTDIR\data\flags\mexico.png"
  Delete "$INSTDIR\data\flags\moldova-shield.png"
  Delete "$INSTDIR\data\flags\moldova.png"
  Delete "$INSTDIR\data\flags\mongolia-shield.png"
  Delete "$INSTDIR\data\flags\mongolia.png"
  Delete "$INSTDIR\data\flags\muskogee-shield.png"
  Delete "$INSTDIR\data\flags\muskogee.png"
  Delete "$INSTDIR\data\flags\myanmar-shield.png"
  Delete "$INSTDIR\data\flags\myanmar.png"
  Delete "$INSTDIR\data\flags\nato-shield.png"
  Delete "$INSTDIR\data\flags\nato.png"
  Delete "$INSTDIR\data\flags\netherlands-shield.png"
  Delete "$INSTDIR\data\flags\netherlands.png"
  Delete "$INSTDIR\data\flags\newzealand-shield.png"
  Delete "$INSTDIR\data\flags\newzealand.png"
  Delete "$INSTDIR\data\flags\nigeria-shield.png"
  Delete "$INSTDIR\data\flags\nigeria.png"
  Delete "$INSTDIR\data\flags\normandy-shield.png"
  Delete "$INSTDIR\data\flags\normandy.png"
  Delete "$INSTDIR\data\flags\north_korea-shield.png"
  Delete "$INSTDIR\data\flags\north_korea.png"
  Delete "$INSTDIR\data\flags\norway-shield.png"
  Delete "$INSTDIR\data\flags\norway.png"
  Delete "$INSTDIR\data\flags\nubia-shield.png"
  Delete "$INSTDIR\data\flags\nubia.png"
  Delete "$INSTDIR\data\flags\numidia-shield.png"
  Delete "$INSTDIR\data\flags\numidia.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth-shield.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth.png"
  Delete "$INSTDIR\data\flags\ottoman-shield.png"
  Delete "$INSTDIR\data\flags\ottoman.png"
  Delete "$INSTDIR\data\flags\pakistan-shield.png"
  Delete "$INSTDIR\data\flags\pakistan.png"
  Delete "$INSTDIR\data\flags\palmyra-shield.png"
  Delete "$INSTDIR\data\flags\palmyra.png"
  Delete "$INSTDIR\data\flags\papua_newguinea-shield.png"
  Delete "$INSTDIR\data\flags\papua_newguinea.png"
  Delete "$INSTDIR\data\flags\peru-shield.png"
  Delete "$INSTDIR\data\flags\peru.png"
  Delete "$INSTDIR\data\flags\philippines-shield.png"
  Delete "$INSTDIR\data\flags\philippines.png"
  Delete "$INSTDIR\data\flags\phoenicia-shield.png"
  Delete "$INSTDIR\data\flags\phoenicia.png"
  Delete "$INSTDIR\data\flags\pirate-shield.png"
  Delete "$INSTDIR\data\flags\pirate.png"
  Delete "$INSTDIR\data\flags\poland-shield.png"
  Delete "$INSTDIR\data\flags\poland.png"
  Delete "$INSTDIR\data\flags\polynesian-shield.png"
  Delete "$INSTDIR\data\flags\polynesian.png"
  Delete "$INSTDIR\data\flags\portugal-shield.png"
  Delete "$INSTDIR\data\flags\portugal.png"
  Delete "$INSTDIR\data\flags\prussia-shield.png"
  Delete "$INSTDIR\data\flags\prussia.png"
  Delete "$INSTDIR\data\flags\purhepecha-shield.png"
  Delete "$INSTDIR\data\flags\purhepecha.png"
  Delete "$INSTDIR\data\flags\qing-shield.png"
  Delete "$INSTDIR\data\flags\qing.png"
  Delete "$INSTDIR\data\flags\quebec-shield.png"
  Delete "$INSTDIR\data\flags\quebec.png"
  Delete "$INSTDIR\data\flags\romania-shield.png"
  Delete "$INSTDIR\data\flags\romania.png"
  Delete "$INSTDIR\data\flags\rome-shield.png"
  Delete "$INSTDIR\data\flags\rome.png"
  Delete "$INSTDIR\data\flags\russia-shield.png"
  Delete "$INSTDIR\data\flags\russia.png"
  Delete "$INSTDIR\data\flags\rwanda-shield.png"
  Delete "$INSTDIR\data\flags\rwanda.png"
  Delete "$INSTDIR\data\flags\ryukyu-shield.png"
  Delete "$INSTDIR\data\flags\ryukyu.png"
  Delete "$INSTDIR\data\flags\samogitia-shield.png"
  Delete "$INSTDIR\data\flags\samogitia.png"
  Delete "$INSTDIR\data\flags\sapmi-shield.png"
  Delete "$INSTDIR\data\flags\sapmi.png"
  Delete "$INSTDIR\data\flags\saxony-shield.png"
  Delete "$INSTDIR\data\flags\saxony.png"
  Delete "$INSTDIR\data\flags\scotland-shield.png"
  Delete "$INSTDIR\data\flags\scotland.png"
  Delete "$INSTDIR\data\flags\serbia-shield.png"
  Delete "$INSTDIR\data\flags\serbia.png"
  Delete "$INSTDIR\data\flags\silesia-shield.png"
  Delete "$INSTDIR\data\flags\silesia.png"
  Delete "$INSTDIR\data\flags\singapore-shield.png"
  Delete "$INSTDIR\data\flags\singapore.png"
  Delete "$INSTDIR\data\flags\slovakia-shield.png"
  Delete "$INSTDIR\data\flags\slovakia.png"
  Delete "$INSTDIR\data\flags\slovenia-shield.png"
  Delete "$INSTDIR\data\flags\slovenia.png"
  Delete "$INSTDIR\data\flags\southern_cross-shield.png"
  Delete "$INSTDIR\data\flags\southern_cross.png"
  Delete "$INSTDIR\data\flags\south_africa-shield.png"
  Delete "$INSTDIR\data\flags\south_africa.png"
  Delete "$INSTDIR\data\flags\soviet-shield.png"
  Delete "$INSTDIR\data\flags\soviet.png"
  Delete "$INSTDIR\data\flags\spain-shield.png"
  Delete "$INSTDIR\data\flags\spain.png"
  Delete "$INSTDIR\data\flags\srilanka-shield.png"
  Delete "$INSTDIR\data\flags\srilanka.png"
  Delete "$INSTDIR\data\flags\srivijaya-shield.png"
  Delete "$INSTDIR\data\flags\srivijaya.png"
  Delete "$INSTDIR\data\flags\stpatrick-shield.png"
  Delete "$INSTDIR\data\flags\stpatrick.png"
  Delete "$INSTDIR\data\flags\sudan-shield.png"
  Delete "$INSTDIR\data\flags\sudan.png"
  Delete "$INSTDIR\data\flags\sumeria-shield.png"
  Delete "$INSTDIR\data\flags\sumeria.png"
  Delete "$INSTDIR\data\flags\swaziland-shield.png"
  Delete "$INSTDIR\data\flags\swaziland.png"
  Delete "$INSTDIR\data\flags\sweden-shield.png"
  Delete "$INSTDIR\data\flags\sweden.png"
  Delete "$INSTDIR\data\flags\swiss-shield.png"
  Delete "$INSTDIR\data\flags\swiss.png"
  Delete "$INSTDIR\data\flags\syria-shield.png"
  Delete "$INSTDIR\data\flags\syria.png"
  Delete "$INSTDIR\data\flags\taino-shield.png"
  Delete "$INSTDIR\data\flags\taino.png"
  Delete "$INSTDIR\data\flags\tairona-shield.png"
  Delete "$INSTDIR\data\flags\tairona.png"
  Delete "$INSTDIR\data\flags\taiwan-shield.png"
  Delete "$INSTDIR\data\flags\taiwan.png"
  Delete "$INSTDIR\data\flags\tajikistan-shield.png"
  Delete "$INSTDIR\data\flags\tajikistan.png"
  Delete "$INSTDIR\data\flags\templar-shield.png"
  Delete "$INSTDIR\data\flags\templar.png"
  Delete "$INSTDIR\data\flags\texas-shield.png"
  Delete "$INSTDIR\data\flags\texas.png"
  Delete "$INSTDIR\data\flags\thailand-shield.png"
  Delete "$INSTDIR\data\flags\thailand.png"
  Delete "$INSTDIR\data\flags\thrace-shield.png"
  Delete "$INSTDIR\data\flags\thrace.png"
  Delete "$INSTDIR\data\flags\tibet-shield.png"
  Delete "$INSTDIR\data\flags\tibet.png"
  Delete "$INSTDIR\data\flags\tocharian-shield.png"
  Delete "$INSTDIR\data\flags\tocharian.png"
  Delete "$INSTDIR\data\flags\tunisia-shield.png"
  Delete "$INSTDIR\data\flags\tunisia.png"
  Delete "$INSTDIR\data\flags\tupi-shield.png"
  Delete "$INSTDIR\data\flags\tupi.png"
  Delete "$INSTDIR\data\flags\turkey-shield.png"
  Delete "$INSTDIR\data\flags\turkey.png"
  Delete "$INSTDIR\data\flags\turkmenistan-shield.png"
  Delete "$INSTDIR\data\flags\turkmenistan.png"
  Delete "$INSTDIR\data\flags\uae-shield.png"
  Delete "$INSTDIR\data\flags\uae.png"
  Delete "$INSTDIR\data\flags\ukraine-shield.png"
  Delete "$INSTDIR\data\flags\ukraine.png"
  Delete "$INSTDIR\data\flags\united_kingdom-shield.png"
  Delete "$INSTDIR\data\flags\united_kingdom.png"
  Delete "$INSTDIR\data\flags\united_nations-shield.png"
  Delete "$INSTDIR\data\flags\united_nations.png"
  Delete "$INSTDIR\data\flags\unknown-shield.png"
  Delete "$INSTDIR\data\flags\unknown.png"
  Delete "$INSTDIR\data\flags\uruguay-shield.png"
  Delete "$INSTDIR\data\flags\uruguay.png"
  Delete "$INSTDIR\data\flags\usa-shield.png"
  Delete "$INSTDIR\data\flags\usa.png"
  Delete "$INSTDIR\data\flags\uyghur-shield.png"
  Delete "$INSTDIR\data\flags\uyghur.png"
  Delete "$INSTDIR\data\flags\uzbekistan-shield.png"
  Delete "$INSTDIR\data\flags\uzbekistan.png"
  Delete "$INSTDIR\data\flags\venezuela-shield.png"
  Delete "$INSTDIR\data\flags\venezuela.png"
  Delete "$INSTDIR\data\flags\vietnam-shield.png"
  Delete "$INSTDIR\data\flags\vietnam.png"
  Delete "$INSTDIR\data\flags\viking-shield.png"
  Delete "$INSTDIR\data\flags\viking.png"
  Delete "$INSTDIR\data\flags\wales-shield.png"
  Delete "$INSTDIR\data\flags\wales.png"
  Delete "$INSTDIR\data\flags\westphalia-shield.png"
  Delete "$INSTDIR\data\flags\westphalia.png"
  Delete "$INSTDIR\data\flags\zulu-shield.png"
  Delete "$INSTDIR\data\flags\zulu.png"
  Delete "$INSTDIR\data\helpdata.txt"
  Delete "$INSTDIR\data\hex2t\grid.png"
  Delete "$INSTDIR\data\hex2t\grid.spec"
  Delete "$INSTDIR\data\hex2t\items.png"
  Delete "$INSTDIR\data\hex2t\items.spec"
  Delete "$INSTDIR\data\hex2t\overlays.png"
  Delete "$INSTDIR\data\hex2t\overlays.spec"
  Delete "$INSTDIR\data\hex2t\select.png"
  Delete "$INSTDIR\data\hex2t\select.spec"
  Delete "$INSTDIR\data\hex2t\tiles.png"
  Delete "$INSTDIR\data\hex2t\tiles.spec"
  Delete "$INSTDIR\data\hex2t.tilespec"
  Delete "$INSTDIR\data\isophex\darkness.png"
  Delete "$INSTDIR\data\isophex\darkness.spec"
  Delete "$INSTDIR\data\isophex\gold.spec"
  Delete "$INSTDIR\data\isophex\grid.png"
  Delete "$INSTDIR\data\isophex\grid.spec"
  Delete "$INSTDIR\data\isophex\rivers.png"
  Delete "$INSTDIR\data\isophex\rivers.spec"
  Delete "$INSTDIR\data\isophex\terrain1.png"
  Delete "$INSTDIR\data\isophex\terrain1.spec"
  Delete "$INSTDIR\data\isophex\terrain2.png"
  Delete "$INSTDIR\data\isophex\terrain2.spec"
  Delete "$INSTDIR\data\isophex\tiles.png"
  Delete "$INSTDIR\data\isophex\tiles.spec"
  Delete "$INSTDIR\data\isophex\water.png"
  Delete "$INSTDIR\data\isophex\water.spec"
  Delete "$INSTDIR\data\isophex.tilespec"
  Delete "$INSTDIR\data\isotrident\cities.png"
  Delete "$INSTDIR\data\isotrident\cities.spec"
  Delete "$INSTDIR\data\isotrident\fog.png"
  Delete "$INSTDIR\data\isotrident\fog.spec"
  Delete "$INSTDIR\data\isotrident\grid.png"
  Delete "$INSTDIR\data\isotrident\grid.spec"
  Delete "$INSTDIR\data\isotrident\morecities.png"
  Delete "$INSTDIR\data\isotrident\morecities.spec"
  Delete "$INSTDIR\data\isotrident\nuke.png"
  Delete "$INSTDIR\data\isotrident\nuke.spec"
  Delete "$INSTDIR\data\isotrident\select.png"
  Delete "$INSTDIR\data\isotrident\select.spec"
  Delete "$INSTDIR\data\isotrident\terrain1.png"
  Delete "$INSTDIR\data\isotrident\terrain1.spec"
  Delete "$INSTDIR\data\isotrident\terrain2.png"
  Delete "$INSTDIR\data\isotrident\terrain2.spec"
  Delete "$INSTDIR\data\isotrident\tiles.png"
  Delete "$INSTDIR\data\isotrident\tiles.spec"
  Delete "$INSTDIR\data\isotrident\unitextras.png"
  Delete "$INSTDIR\data\isotrident\unitextras.spec"
  Delete "$INSTDIR\data\isotrident\water.png"
  Delete "$INSTDIR\data\isotrident\water.spec"
  Delete "$INSTDIR\data\isotrident.tilespec"
  Delete "$INSTDIR\data\misc\buildings.png"
  Delete "$INSTDIR\data\misc\buildings.spec"
  Delete "$INSTDIR\data\misc\chiefs.png"
  Delete "$INSTDIR\data\misc\chiefs.spec"
  Delete "$INSTDIR\data\misc\citybar.png"
  Delete "$INSTDIR\data\misc\citybar.spec"
  Delete "$INSTDIR\data\misc\cityicon.png"
  Delete "$INSTDIR\data\misc\civicon.png"
  Delete "$INSTDIR\data\misc\colors.png"
  Delete "$INSTDIR\data\misc\colors.spec"
  Delete "$INSTDIR\data\misc\colors.tilespec"
  Delete "$INSTDIR\data\misc\cursors.png"
  Delete "$INSTDIR\data\misc\cursors.spec"
  Delete "$INSTDIR\data\misc\editor.png"
  Delete "$INSTDIR\data\misc\editor.spec"
  Delete "$INSTDIR\data\misc\flags.spec"
  Delete "$INSTDIR\data\misc\icons.spec"
  Delete "$INSTDIR\data\misc\intro.png"
  Delete "$INSTDIR\data\misc\overlays.png"
  Delete "$INSTDIR\data\misc\overlays.spec"
  Delete "$INSTDIR\data\misc\radar.png"
  Delete "$INSTDIR\data\misc\shields.spec"
  Delete "$INSTDIR\data\misc\small.png"
  Delete "$INSTDIR\data\misc\small.spec"
  Delete "$INSTDIR\data\misc\space.png"
  Delete "$INSTDIR\data\misc\space.spec"
  Delete "$INSTDIR\data\misc\techs.png"
  Delete "$INSTDIR\data\misc\techs.spec"
  Delete "$INSTDIR\data\misc\treaty.png"
  Delete "$INSTDIR\data\misc\treaty.spec"
  Delete "$INSTDIR\data\nation\aborigines.ruleset"
  Delete "$INSTDIR\data\nation\afghani.ruleset"
  Delete "$INSTDIR\data\nation\ainu.ruleset"
  Delete "$INSTDIR\data\nation\akwe.ruleset"
  Delete "$INSTDIR\data\nation\algerian.ruleset"
  Delete "$INSTDIR\data\nation\american.ruleset"
  Delete "$INSTDIR\data\nation\antarctican.ruleset"
  Delete "$INSTDIR\data\nation\arab.ruleset"
  Delete "$INSTDIR\data\nation\aramean.ruleset"
  Delete "$INSTDIR\data\nation\argentine.ruleset"
  Delete "$INSTDIR\data\nation\armenian.ruleset"
  Delete "$INSTDIR\data\nation\assyrian.ruleset"
  Delete "$INSTDIR\data\nation\australian.ruleset"
  Delete "$INSTDIR\data\nation\austrian.ruleset"
  Delete "$INSTDIR\data\nation\aymara.ruleset"
  Delete "$INSTDIR\data\nation\azeri.ruleset"
  Delete "$INSTDIR\data\nation\aztec.ruleset"
  Delete "$INSTDIR\data\nation\babylonian.ruleset"
  Delete "$INSTDIR\data\nation\barbarian.ruleset"
  Delete "$INSTDIR\data\nation\basque.ruleset"
  Delete "$INSTDIR\data\nation\bavarian.ruleset"
  Delete "$INSTDIR\data\nation\belarusian.ruleset"
  Delete "$INSTDIR\data\nation\belgian.ruleset"
  Delete "$INSTDIR\data\nation\bengali.ruleset"
  Delete "$INSTDIR\data\nation\boer.ruleset"
  Delete "$INSTDIR\data\nation\bosnia.ruleset"
  Delete "$INSTDIR\data\nation\brazilian.ruleset"
  Delete "$INSTDIR\data\nation\breton.ruleset"
  Delete "$INSTDIR\data\nation\british.ruleset"
  Delete "$INSTDIR\data\nation\bulgarian.ruleset"
  Delete "$INSTDIR\data\nation\burgundian.ruleset"
  Delete "$INSTDIR\data\nation\burmese.ruleset"
  Delete "$INSTDIR\data\nation\burundi.ruleset"
  Delete "$INSTDIR\data\nation\byzantium.ruleset"
  Delete "$INSTDIR\data\nation\cambodian.ruleset"
  Delete "$INSTDIR\data\nation\canadian.ruleset"
  Delete "$INSTDIR\data\nation\carthaginian.ruleset"
  Delete "$INSTDIR\data\nation\catalan.ruleset"
  Delete "$INSTDIR\data\nation\cherokee.ruleset"
  Delete "$INSTDIR\data\nation\chilean.ruleset"
  Delete "$INSTDIR\data\nation\chinese.ruleset"
  Delete "$INSTDIR\data\nation\chola.ruleset"
  Delete "$INSTDIR\data\nation\colombian.ruleset"
  Delete "$INSTDIR\data\nation\confederate.ruleset"
  Delete "$INSTDIR\data\nation\cornish.ruleset"
  Delete "$INSTDIR\data\nation\cree.ruleset"
  Delete "$INSTDIR\data\nation\croatian.ruleset"
  Delete "$INSTDIR\data\nation\cuban.ruleset"
  Delete "$INSTDIR\data\nation\czech.ruleset"
  Delete "$INSTDIR\data\nation\danish.ruleset"
  Delete "$INSTDIR\data\nation\dominican.ruleset"
  Delete "$INSTDIR\data\nation\dutch.ruleset"
  Delete "$INSTDIR\data\nation\egyptian.ruleset"
  Delete "$INSTDIR\data\nation\emirati.ruleset"
  Delete "$INSTDIR\data\nation\english.ruleset"
  Delete "$INSTDIR\data\nation\esperant.ruleset"
  Delete "$INSTDIR\data\nation\estonian.ruleset"
  Delete "$INSTDIR\data\nation\ethiopian.ruleset"
  Delete "$INSTDIR\data\nation\european.ruleset"
  Delete "$INSTDIR\data\nation\filipino.ruleset"
  Delete "$INSTDIR\data\nation\finnish.ruleset"
  Delete "$INSTDIR\data\nation\french.ruleset"
  Delete "$INSTDIR\data\nation\galician.ruleset"
  Delete "$INSTDIR\data\nation\gallic.ruleset"
  Delete "$INSTDIR\data\nation\georgian.ruleset"
  Delete "$INSTDIR\data\nation\german.ruleset"
  Delete "$INSTDIR\data\nation\greek.ruleset"
  Delete "$INSTDIR\data\nation\gupta.ruleset"
  Delete "$INSTDIR\data\nation\hacker.ruleset"
  Delete "$INSTDIR\data\nation\hawaiian.ruleset"
  Delete "$INSTDIR\data\nation\hellenic.ruleset"
  Delete "$INSTDIR\data\nation\himyarite.ruleset"
  Delete "$INSTDIR\data\nation\hittite.ruleset"
  Delete "$INSTDIR\data\nation\hopi.ruleset"
  Delete "$INSTDIR\data\nation\hungarian.ruleset"
  Delete "$INSTDIR\data\nation\icelandic.ruleset"
  Delete "$INSTDIR\data\nation\illyrian.ruleset"
  Delete "$INSTDIR\data\nation\inca.ruleset"
  Delete "$INSTDIR\data\nation\indian.ruleset"
  Delete "$INSTDIR\data\nation\indonesian.ruleset"
  Delete "$INSTDIR\data\nation\inuit.ruleset"
  Delete "$INSTDIR\data\nation\iranian.ruleset"
  Delete "$INSTDIR\data\nation\iraqi.ruleset"
  Delete "$INSTDIR\data\nation\irish.ruleset"
  Delete "$INSTDIR\data\nation\iroquois.ruleset"
  Delete "$INSTDIR\data\nation\israeli.ruleset"
  Delete "$INSTDIR\data\nation\italian.ruleset"
  Delete "$INSTDIR\data\nation\japanese.ruleset"
  Delete "$INSTDIR\data\nation\kanem-bornu.ruleset"
  Delete "$INSTDIR\data\nation\kazakh.ruleset"
  Delete "$INSTDIR\data\nation\kenyan.ruleset"
  Delete "$INSTDIR\data\nation\khwarezmian.ruleset"
  Delete "$INSTDIR\data\nation\kongo.ruleset"
  Delete "$INSTDIR\data\nation\korean.ruleset"
  Delete "$INSTDIR\data\nation\kurd.ruleset"
  Delete "$INSTDIR\data\nation\kyrgyz.ruleset"
  Delete "$INSTDIR\data\nation\lankese.ruleset"
  Delete "$INSTDIR\data\nation\laotian.ruleset"
  Delete "$INSTDIR\data\nation\latvian.ruleset"
  Delete "$INSTDIR\data\nation\libyan.ruleset"
  Delete "$INSTDIR\data\nation\lithuanian.ruleset"
  Delete "$INSTDIR\data\nation\lojbanistani.ruleset"
  Delete "$INSTDIR\data\nation\majapahit.ruleset"
  Delete "$INSTDIR\data\nation\malagasy.ruleset"
  Delete "$INSTDIR\data\nation\malaysian.ruleset"
  Delete "$INSTDIR\data\nation\malian.ruleset"
  Delete "$INSTDIR\data\nation\manchu.ruleset"
  Delete "$INSTDIR\data\nation\maori.ruleset"
  Delete "$INSTDIR\data\nation\mapuche.ruleset"
  Delete "$INSTDIR\data\nation\martian.ruleset"
  Delete "$INSTDIR\data\nation\mayan.ruleset"
  Delete "$INSTDIR\data\nation\mexican.ruleset"
  Delete "$INSTDIR\data\nation\moldovan.ruleset"
  Delete "$INSTDIR\data\nation\mongol.ruleset"
  Delete "$INSTDIR\data\nation\muskogee.ruleset"
  Delete "$INSTDIR\data\nation\newzealand.ruleset"
  Delete "$INSTDIR\data\nation\nigerian.ruleset"
  Delete "$INSTDIR\data\nation\norman.ruleset"
  Delete "$INSTDIR\data\nation\northkorean.ruleset"
  Delete "$INSTDIR\data\nation\norwegian.ruleset"
  Delete "$INSTDIR\data\nation\nubian.ruleset"
  Delete "$INSTDIR\data\nation\numidian.ruleset"
  Delete "$INSTDIR\data\nation\nuu-chah-nulth.ruleset"
  Delete "$INSTDIR\data\nation\ottoman.ruleset"
  Delete "$INSTDIR\data\nation\pakistani.ruleset"
  Delete "$INSTDIR\data\nation\papuan.ruleset"
  Delete "$INSTDIR\data\nation\persian.ruleset"
  Delete "$INSTDIR\data\nation\peruvian.ruleset"
  Delete "$INSTDIR\data\nation\phoenician.ruleset"
  Delete "$INSTDIR\data\nation\pirate.ruleset"
  Delete "$INSTDIR\data\nation\polish.ruleset"
  Delete "$INSTDIR\data\nation\polynesian.ruleset"
  Delete "$INSTDIR\data\nation\portuguese.ruleset"
  Delete "$INSTDIR\data\nation\prussian.ruleset"
  Delete "$INSTDIR\data\nation\purhepecha.ruleset"
  Delete "$INSTDIR\data\nation\quebecois.ruleset"
  Delete "$INSTDIR\data\nation\roman.ruleset"
  Delete "$INSTDIR\data\nation\romanian.ruleset"
  Delete "$INSTDIR\data\nation\russian.ruleset"
  Delete "$INSTDIR\data\nation\rwandan.ruleset"
  Delete "$INSTDIR\data\nation\ryukyuan.ruleset"
  Delete "$INSTDIR\data\nation\sami.ruleset"
  Delete "$INSTDIR\data\nation\samogitian.ruleset"
  Delete "$INSTDIR\data\nation\saxon.ruleset"
  Delete "$INSTDIR\data\nation\scottish.ruleset"
  Delete "$INSTDIR\data\nation\serbian.ruleset"
  Delete "$INSTDIR\data\nation\silesian.ruleset"
  Delete "$INSTDIR\data\nation\singaporean.ruleset"
  Delete "$INSTDIR\data\nation\sioux.ruleset"
  Delete "$INSTDIR\data\nation\slovakian.ruleset"
  Delete "$INSTDIR\data\nation\slovenian.ruleset"
  Delete "$INSTDIR\data\nation\southafrican.ruleset"
  Delete "$INSTDIR\data\nation\southkorean.ruleset"
  Delete "$INSTDIR\data\nation\soviet.ruleset"
  Delete "$INSTDIR\data\nation\spanish.ruleset"
  Delete "$INSTDIR\data\nation\srivijaya.ruleset"
  Delete "$INSTDIR\data\nation\sudanese.ruleset"
  Delete "$INSTDIR\data\nation\sumerian.ruleset"
  Delete "$INSTDIR\data\nation\swazi.ruleset"
  Delete "$INSTDIR\data\nation\swedish.ruleset"
  Delete "$INSTDIR\data\nation\swiss.ruleset"
  Delete "$INSTDIR\data\nation\syrian.ruleset"
  Delete "$INSTDIR\data\nation\taino.ruleset"
  Delete "$INSTDIR\data\nation\tairona.ruleset"
  Delete "$INSTDIR\data\nation\taiwanese.ruleset"
  Delete "$INSTDIR\data\nation\tajik.ruleset"
  Delete "$INSTDIR\data\nation\templar.ruleset"
  Delete "$INSTDIR\data\nation\texan.ruleset"
  Delete "$INSTDIR\data\nation\thai.ruleset"
  Delete "$INSTDIR\data\nation\thracian.ruleset"
  Delete "$INSTDIR\data\nation\tibetan.ruleset"
  Delete "$INSTDIR\data\nation\tocharian.ruleset"
  Delete "$INSTDIR\data\nation\tunisian.ruleset"
  Delete "$INSTDIR\data\nation\tupi.ruleset"
  Delete "$INSTDIR\data\nation\turk.ruleset"
  Delete "$INSTDIR\data\nation\turkmen.ruleset"
  Delete "$INSTDIR\data\nation\ukrainian.ruleset"
  Delete "$INSTDIR\data\nation\un.ruleset"
  Delete "$INSTDIR\data\nation\uruguayan.ruleset"
  Delete "$INSTDIR\data\nation\uyghur.ruleset"
  Delete "$INSTDIR\data\nation\uzbek.ruleset"
  Delete "$INSTDIR\data\nation\venezuelan.ruleset"
  Delete "$INSTDIR\data\nation\vietnamese.ruleset"
  Delete "$INSTDIR\data\nation\viking.ruleset"
  Delete "$INSTDIR\data\nation\welsh.ruleset"
  Delete "$INSTDIR\data\nation\westphalian.ruleset"
  Delete "$INSTDIR\data\nation\zulu.ruleset"
  Delete "$INSTDIR\data\scenario\british-isles-85x80-v2.80.sav.gz"
  Delete "$INSTDIR\data\scenario\earth-160x90-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\earth-80x50-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\europe-200x100-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\france-140x90-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\hagworld-120x60-v1.2.sav.gz"
  Delete "$INSTDIR\data\scenario\iberian-peninsula-136x100-v1.0.sav.gz"
  Delete "$INSTDIR\data\scenario\italy-100x100-v1.5.sav.gz"
  Delete "$INSTDIR\data\scenario\japan-88x100-v1.3.sav.gz"
  Delete "$INSTDIR\data\scenario\north_america_116x100-v1.2.sav.gz"
  Delete "$INSTDIR\data\scenario\tutorial.sav.gz"
  Delete "$INSTDIR\data\stdsounds\foot3.ogg"
  Delete "$INSTDIR\data\stdsounds\inh2o.ogg"
  Delete "$INSTDIR\data\stdsounds\LrgCan.ogg"
  Delete "$INSTDIR\data\stdsounds\LrgExpl.ogg"
  Delete "$INSTDIR\data\stdsounds\MedCan.ogg"
  Delete "$INSTDIR\data\stdsounds\metbrk.ogg"
  Delete "$INSTDIR\data\stdsounds\MgBar1.ogg"
  Delete "$INSTDIR\data\stdsounds\MgBar2.ogg"
  Delete "$INSTDIR\data\stdsounds\MgHeavy.ogg"
  Delete "$INSTDIR\data\stdsounds\Mortar.ogg"
  Delete "$INSTDIR\data\stdsounds\SmlExpl.ogg"
  Delete "$INSTDIR\data\stdsounds\Splash.ogg"
  Delete "$INSTDIR\data\stdsounds\THover.ogg"
  Delete "$INSTDIR\data\stdsounds\Tread.ogg"
  Delete "$INSTDIR\data\stdsounds\wall01.ogg"
  Delete "$INSTDIR\data\stdsounds\woodbrk.ogg"
  Delete "$INSTDIR\data\stdsounds.soundspec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\backgrounds.themespec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\bg.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\bg2.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\city.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\city.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\city_fist.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\city_fist.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\colors.themespec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\COPYING.DejaVu"
  Delete "$INSTDIR\data\themes\gui-sdl\human\COPYING.fireflysung"
  Delete "$INSTDIR\data\themes\gui-sdl\human\COPYING.sazanami"
  Delete "$INSTDIR\data\themes\gui-sdl\human\COPYING.UnDotum"
  Delete "$INSTDIR\data\themes\gui-sdl\human\DejaVuSans.ttf"
  Delete "$INSTDIR\data\themes\gui-sdl\human\dip_icons.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\dip_icons.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\fireflysung.ttf"
  Delete "$INSTDIR\data\themes\gui-sdl\human\icons.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\icons.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\intro.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\options_bg.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\sazanami-gothic.ttf"
  Delete "$INSTDIR\data\themes\gui-sdl\human\small_theme_buttons.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\small_theme_buttons.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\tech_tree.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\tech_tree.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme.themespec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_boxs.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_boxs.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_buttons.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_buttons.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_orders_buttons.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_orders_buttons.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_scrolls.png"
  Delete "$INSTDIR\data\themes\gui-sdl\human\theme_scrolls.spec"
  Delete "$INSTDIR\data\themes\gui-sdl\human\UnDotum.ttf"
  Delete "$INSTDIR\data\themes\gui-sdl\human\world.png"
  Delete "$INSTDIR\data\trident\auto_ll.spec"
  Delete "$INSTDIR\data\trident\cities.png"
  Delete "$INSTDIR\data\trident\cities.spec"
  Delete "$INSTDIR\data\trident\earth.png"
  Delete "$INSTDIR\data\trident\earth.spec"
  Delete "$INSTDIR\data\trident\explosions.png"
  Delete "$INSTDIR\data\trident\explosions.spec"
  Delete "$INSTDIR\data\trident\fog.png"
  Delete "$INSTDIR\data\trident\fog.spec"
  Delete "$INSTDIR\data\trident\grid.png"
  Delete "$INSTDIR\data\trident\grid.spec"
  Delete "$INSTDIR\data\trident\roads.png"
  Delete "$INSTDIR\data\trident\roads.spec"
  Delete "$INSTDIR\data\trident\select.png"
  Delete "$INSTDIR\data\trident\select.spec"
  Delete "$INSTDIR\data\trident\tiles.png"
  Delete "$INSTDIR\data\trident\tiles.spec"
  Delete "$INSTDIR\data\trident\units.png"
  Delete "$INSTDIR\data\trident\units.spec"
  Delete "$INSTDIR\data\trident.tilespec"
  Delete "$INSTDIR\data\wonders\apollo_program.png"
  Delete "$INSTDIR\data\wonders\asmiths_trading_co.png"
  Delete "$INSTDIR\data\wonders\colossus.png"
  Delete "$INSTDIR\data\wonders\copernicus_observatory.png"
  Delete "$INSTDIR\data\wonders\cure_for_cancer.png"
  Delete "$INSTDIR\data\wonders\darwins_voyage.png"
  Delete "$INSTDIR\data\wonders\eiffel_tower.png"
  Delete "$INSTDIR\data\wonders\great_library.png"
  Delete "$INSTDIR\data\wonders\great_wall.png"
  Delete "$INSTDIR\data\wonders\hanging_gardens.png"
  Delete "$INSTDIR\data\wonders\hoover_dam.png"
  Delete "$INSTDIR\data\wonders\isaac_newtons_college.png"
  Delete "$INSTDIR\data\wonders\js_bachs_cathedral.png"
  Delete "$INSTDIR\data\wonders\king_richards_crusade.png"
  Delete "$INSTDIR\data\wonders\leonardos_workshop.png"
  Delete "$INSTDIR\data\wonders\lighthouse.png"
  Delete "$INSTDIR\data\wonders\magellans_expedition.png"
  Delete "$INSTDIR\data\wonders\manhattan_project.png"
  Delete "$INSTDIR\data\wonders\marco_polos_embassy.png"
  Delete "$INSTDIR\data\wonders\michelangelos_chapel.png"
  Delete "$INSTDIR\data\wonders\oracle.png"
  Delete "$INSTDIR\data\wonders\pyramids.png"
  Delete "$INSTDIR\data\wonders\seti_program.png"
  Delete "$INSTDIR\data\wonders\shakespeares_theatre.png"
  Delete "$INSTDIR\data\wonders\statue_of_liberty.png"
  Delete "$INSTDIR\data\wonders\sun_tzus_war_academy.png"
  Delete "$INSTDIR\data\wonders\united_nations.png"
  Delete "$INSTDIR\data\wonders\womens_suffrage.png"
  Delete "$INSTDIR\doc\BUGS"
  Delete "$INSTDIR\doc\ca\BUGS.ca"
  Delete "$INSTDIR\doc\ca\HOWTOPLAY.ca"
  Delete "$INSTDIR\doc\ca\README.ca"
  Delete "$INSTDIR\doc\CodingStyle"
  Delete "$INSTDIR\doc\de\BUGS.de"
  Delete "$INSTDIR\doc\de\HOWTOPLAY.de"
  Delete "$INSTDIR\doc\de\INSTALL.de"
  Delete "$INSTDIR\doc\de\README.de"
  Delete "$INSTDIR\doc\FAQ"
  Delete "$INSTDIR\doc\fr\BUGS.fr"
  Delete "$INSTDIR\doc\fr\HOWTOPLAY.fr"
  Delete "$INSTDIR\doc\fr\INSTALL.fr"
  Delete "$INSTDIR\doc\fr\README.fr"
  Delete "$INSTDIR\doc\HACKING"
  Delete "$INSTDIR\doc\HOWTOPLAY"
  Delete "$INSTDIR\doc\INSTALL.Cygwin"
  Delete "$INSTDIR\doc\it\HOWTOPLAY.it"
  Delete "$INSTDIR\doc\it\INSTALL.it"
  Delete "$INSTDIR\doc\it\README.it"
  Delete "$INSTDIR\doc\ja\BUGS.ja"
  Delete "$INSTDIR\doc\ja\HOWTOPLAY.ja"
  Delete "$INSTDIR\doc\ja\README.ja"
  Delete "$INSTDIR\doc\man\freeciv-client.6"
  Delete "$INSTDIR\doc\man\freeciv-ftwl.6"
  Delete "$INSTDIR\doc\man\freeciv-gtk2.6"
  Delete "$INSTDIR\doc\man\freeciv-sdl.6"
  Delete "$INSTDIR\doc\man\freeciv-server.6"
  Delete "$INSTDIR\doc\man\freeciv-win32.6"
  Delete "$INSTDIR\doc\man\freeciv-xaw.6"
  Delete "$INSTDIR\doc\nl\BUGS.nl"
  Delete "$INSTDIR\doc\nl\HOWTOPLAY.nl"
  Delete "$INSTDIR\doc\nl\README.nl"
  Delete "$INSTDIR\doc\README"
  Delete "$INSTDIR\doc\README.agents"
  Delete "$INSTDIR\doc\README.AI"
  Delete "$INSTDIR\doc\README.attributes"
  Delete "$INSTDIR\doc\README.cma"
  Delete "$INSTDIR\doc\README.delta"
  Delete "$INSTDIR\doc\README.effects"
  Delete "$INSTDIR\doc\README.ftwl"
  Delete "$INSTDIR\doc\README.graphics"
  Delete "$INSTDIR\doc\README.nations"
  Delete "$INSTDIR\doc\README.rulesets"
  Delete "$INSTDIR\doc\README.scorelog"
  Delete "$INSTDIR\doc\README.SDLClient"
  Delete "$INSTDIR\doc\README.sound"
  Delete "$INSTDIR\doc\sv\BUGS.sv"
  Delete "$INSTDIR\doc\sv\HOWTOPLAY.sv"
  Delete "$INSTDIR\doc\sv\README.sv"
  Delete "$INSTDIR\doc\TODO"
  Delete "$INSTDIR\exchndl.dll"
  Delete "$INSTDIR\freeciv-sdl.exe"
  Delete "$INSTDIR\freeciv-server.exe"
  Delete "$INSTDIR\Freeciv.url"
  Delete "$INSTDIR\freetype6.dll"
  Delete "$INSTDIR\iconv.dll"
  Delete "$INSTDIR\INSTALL"
  Delete "$INSTDIR\intl.dll"
  Delete "$INSTDIR\libogg-0.dll"
  Delete "$INSTDIR\libpng12-0.dll"
  Delete "$INSTDIR\libvorbis-0.dll"
  Delete "$INSTDIR\libvorbisfile-3.dll"
  Delete "$INSTDIR\NEWS"
  Delete "$INSTDIR\README"
  Delete "$INSTDIR\SDL.dll"
  Delete "$INSTDIR\SDL_image.dll"
  Delete "$INSTDIR\SDL_mixer.dll"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\no\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\zlib1.dll"
  RMDir "$INSTDIR\data\amplio"
  RMDir "$INSTDIR\data\buildings"
  RMDir "$INSTDIR\data\civ1"
  RMDir "$INSTDIR\data\civ2"
  RMDir "$INSTDIR\data\default"
  RMDir "$INSTDIR\data\flags"
  RMDir "$INSTDIR\data\hex2t"
  RMDir "$INSTDIR\data\isophex"
  RMDir "$INSTDIR\data\isotrident"
  RMDir "$INSTDIR\data\misc"
  RMDir "$INSTDIR\data\nation"
  RMDir "$INSTDIR\data\scenario"
  RMDir "$INSTDIR\data\stdsounds"
  RMDir "$INSTDIR\data\themes\gui-sdl\human"
  RMDir "$INSTDIR\data\themes\gui-sdl"
  RMDir "$INSTDIR\data\themes"
  RMDir "$INSTDIR\data\trident"
  RMDir "$INSTDIR\data\wonders"
  RMDir "$INSTDIR\data"
  RMDir "$INSTDIR\doc\ca"
  RMDir "$INSTDIR\doc\de"
  RMDir "$INSTDIR\doc\fr"
  RMDir "$INSTDIR\doc\it"
  RMDir "$INSTDIR\doc\ja"
  RMDir "$INSTDIR\doc\man"
  RMDir "$INSTDIR\doc\nl"
  RMDir "$INSTDIR\doc\sv"
  RMDir "$INSTDIR\doc"
  RMDir "$INSTDIR\share\locale\ar\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ar"
  RMDir "$INSTDIR\share\locale\ca\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ca"
  RMDir "$INSTDIR\share\locale\cs\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\cs"
  RMDir "$INSTDIR\share\locale\da\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\da"
  RMDir "$INSTDIR\share\locale\de\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\de"
  RMDir "$INSTDIR\share\locale\el\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\el"
  RMDir "$INSTDIR\share\locale\en_GB\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\en_GB"
  RMDir "$INSTDIR\share\locale\eo\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\eo"
  RMDir "$INSTDIR\share\locale\es\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\es"
  RMDir "$INSTDIR\share\locale\et\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\et"
  RMDir "$INSTDIR\share\locale\fa\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fa"
  RMDir "$INSTDIR\share\locale\fi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fi"
  RMDir "$INSTDIR\share\locale\fr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fr"
  RMDir "$INSTDIR\share\locale\he\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\he"
  RMDir "$INSTDIR\share\locale\hu\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\hu"
  RMDir "$INSTDIR\share\locale\it\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\it"
  RMDir "$INSTDIR\share\locale\ja\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ja"
  RMDir "$INSTDIR\share\locale\ko\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ko"
  RMDir "$INSTDIR\share\locale\lt\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\lt"
  RMDir "$INSTDIR\share\locale\nb\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nb"
  RMDir "$INSTDIR\share\locale\nl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nl"
  RMDir "$INSTDIR\share\locale\no\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\no"
  RMDir "$INSTDIR\share\locale\pl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pl"
  RMDir "$INSTDIR\share\locale\pt\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pt"
  RMDir "$INSTDIR\share\locale\pt_BR\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pt_BR"
  RMDir "$INSTDIR\share\locale\ro\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ro"
  RMDir "$INSTDIR\share\locale\ru\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ru"
  RMDir "$INSTDIR\share\locale\sv\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sv"
  RMDir "$INSTDIR\share\locale\tr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\tr"
  RMDir "$INSTDIR\share\locale\uk\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\uk"
  RMDir "$INSTDIR\share\locale\zh_CN\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\zh_CN"
  RMDir "$INSTDIR\share\locale"
  RMDir "$INSTDIR\share"
  RMDir "$INSTDIR"

  ; MUST REMOVE UNINSTALLER, too
  Delete $INSTDIR\uninstall.exe

  ; remove shortcuts, if any.
  !insertmacro MUI_STARTMENU_GETFOLDER "Application" $STARTMENU_FOLDER
  Delete "$SMPROGRAMS\$STARTMENU_FOLDER\*.*"
  RMDir "$SMPROGRAMS\$STARTMENU_FOLDER"

  ; remove registry keys
  DeleteRegKey "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}"
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}\${VERSION}\${GUI_ID}
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}\${VERSION}
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}
SectionEnd
;--------------------------------
;Uninstaller Functions

Function un.onInit

  !insertmacro MULTIUSER_UNINIT

FunctionEnd

